@@ -95,7 +95,12 @@ extern char* gl_buf;
 static int* globalIntegerInternals[] = {
   &rl_readline_version,
   &rl_gnu_readline_p,
+#if (RL_READLINE_VERSION >= 0x0700)
+  /* in readline 7.0, this field was changed to a long int. It's still holds a 32bit value so we'll cast. */
+  (int *) &rl_readline_state,
+#else
   &rl_readline_state,
+#endif
   &rl_editing_mode,
   &rl_insert_mode,
   &rl_point,
@@ -130,18 +135,18 @@ static int* globalIntegerInternals[] = {
 };
 
 static char** globalStringInternals[] = {
- /* const */ &rl_library_version,
- /* const */ &rl_readline_name,
+ /* const */ (char**) &rl_library_version,
+ /* const */ (char**) &rl_readline_name,
  &rl_prompt,
  &rl_line_buffer,
- /* const */ &rl_terminal_name,
+ /* const */ (char**) &rl_terminal_name,
  &rl_executing_macro,
- /* const */ &rl_basic_word_break_characters,
- /* const */ &rl_completer_word_break_characters,
- /* const */ &rl_completer_quote_characters,
- /* const */ &rl_basic_quote_characters,
- /* const */ &rl_filename_quote_characters,
- /* const */ &rl_special_prefixes,
+ /* const */ (char**) &rl_basic_word_break_characters,
+ /* const */ (char**) &rl_completer_word_break_characters,
+ /* const */ (char**) &rl_completer_quote_characters,
+ /* const */ (char**) &rl_basic_quote_characters,
+ /* const */ (char**) &rl_filename_quote_characters,
+ /* const */ (char**) &rl_special_prefixes,
 
  &history_word_delimiters,
  &history_no_expand_chars,
@@ -198,18 +203,18 @@ static int* globalIntegerInternals[] = {
 };
 
 static char** globalStringInternals[] = {
-  /* const */ &rl_library_version,
-  /* const */ &rl_readline_name,
+  /* const */ (char**) &rl_library_version,
+  /* const */ (char**) &rl_readline_name,
   &undefinedInternalString, /*  &rl_prompt, */
   &rl_line_buffer,
   &undefinedInternalString, /* const  &rl_terminal_name, */
   &undefinedInternalString, /*  &rl_executing_macro, */
-  /* const */ &rl_basic_word_break_characters,
-  /* const */ &rl_completer_word_break_characters,
-  /* const */ &rl_completer_quote_characters,
+  /* const */ (char**) &rl_basic_word_break_characters,
+  /* const */ (char**) &rl_completer_word_break_characters,
+  /* const */ (char**) &rl_completer_quote_characters,
   &undefinedInternalString, /* const  &rl_basic_quote_characters, */
   &undefinedInternalString, /* const  &rl_filename_quote_characters, */
-  /* const */ &rl_special_prefixes,
+  /* const */ (char**) &rl_special_prefixes,
 
   &undefinedInternalString, /*  &history_word_delimiters, */
   &undefinedInternalString, /*  &history_no_expand_chars, */
@@ -307,8 +312,8 @@ static size_t bufLength = 0;
 
 static char*  word_break_buffer = NULL;
 
-static char* fromjstring(const JNIEnv *env, jstring value);
-static jstring tojstring(const JNIEnv *env, const char* value);
+static char* fromjstring(JNIEnv *const env, jstring value);
+static jstring tojstring(JNIEnv *const env, const char* value);
 
 static int   allocBuffer(size_t n);
 
@@ -776,7 +781,7 @@ JNIEXPORT jstring JNICALL
 /* Convert jstring to c-string                                                */
 /* -------------------------------------------------------------------------- */
 
-char* fromjstring(const JNIEnv *env, jstring value) {
+char* fromjstring(JNIEnv *const env, jstring value) {
   const jclass jstringClass = (*env)->GetObjectClass(env, value);
   const jmethodID getBytesMethodId = (*env)->GetMethodID(env, jstringClass, "getBytes", "()[B");
 
@@ -790,7 +795,7 @@ char* fromjstring(const JNIEnv *env, jstring value) {
     return NULL;
   }
 
-  const jbyte* bytes = (*env)->GetByteArrayElements(env, jstringJBytes, NULL);
+  jbyte *const bytes = (*env)->GetByteArrayElements(env, jstringJBytes, NULL);
 
   if (2*length > bufLength) {
     if (allocBuffer(2*length)) {
@@ -822,7 +827,7 @@ char* fromjstring(const JNIEnv *env, jstring value) {
 /* Convert c-string to j-string                                               */
 /* -------------------------------------------------------------------------- */
 
-jstring tojstring(const JNIEnv *env, const char* value) {
+jstring tojstring(JNIEnv *const env, const char* value) {
   const jclass jstringClass = (*env)->FindClass(env,"java/lang/String");
   const jmethodID constructorMethodId = (*env)->GetMethodID(env, jstringClass, "<init>", "([B)V");
 
